"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var kebabCase = function (str) {
    return str
        .replace(/([a-z])([A-Z])/g, '$1-$2')
        .replace(/\s+/g, '-')
        .toLowerCase();
};
function toHaveCompiledCss(element) {
    var _a;
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    var property = args[0], value = args[1];
    var properties = typeof property === 'string' ? (_a = {}, _a[property] = value, _a) : property;
    var styleElement = element.parentElement && element.parentElement.querySelector('style');
    if (!styleElement) {
        // There wasn't a style element found within - let's check the head for it instead.
        var styleElements = Array.from(document.head.querySelectorAll('style'));
        for (var _b = 0, styleElements_1 = styleElements; _b < styleElements_1.length; _b++) {
            var tag = styleElements_1[_b];
            if (tag.innerHTML.includes(element.className)) {
                styleElement = tag;
                break;
            }
        }
    }
    if (!styleElement) {
        return {
            pass: false,
            message: function () { return 'pairing style element was not found'; },
        };
    }
    // This is a hack to get ahold of the styles.
    // Unfortunately JSDOM doesn't handle css variables properly
    // See: https://github.com/jsdom/jsdom/issues/1895
    // @ts-ignore
    var styles = element[Object.keys(element)[0]].memoizedProps.style;
    var css = styleElement.textContent || '';
    if (styles && Object.keys(styles).length > 0) {
        Object.entries(styles).forEach(function (_a) {
            var key = _a[0], value = _a[1];
            // Replace all instances of var with the value.
            // We split and join to replace all instances without needing to jump into a dynamic regex.
            css = css.split("var(" + key + ")").join(value);
        });
    }
    var stylesToFind = Object.keys(properties).map(function (property) { return kebabCase(property) + ":" + properties[property]; });
    var foundStyles = stylesToFind.filter(function (styleToFind) { return css.includes(styleToFind); });
    var notFoundStyles = stylesToFind.filter(function (styleToFind) { return !css.includes(styleToFind); });
    var includedSelector = css.includes("." + element.className);
    if (includedSelector && foundStyles.length > 0 && notFoundStyles.length === 0) {
        return {
            pass: true,
            message: !this.isNot
                ? function () { return ''; }
                : function () { return "Found \"" + foundStyles.join(', ') + "\" on <" + element.nodeName.toLowerCase() + " " + (styles &&
                    "style={" + JSON.stringify(styles) + "}") + "> element.\n\n  Reconciled css (css variables replaced with actual values):\n  " + css + "\n\n  Original css:\n  " + ((styleElement && styleElement.textContent) || '') + "\n  "; },
        };
    }
    return {
        pass: false,
        message: function () { return "Could not find \"" + notFoundStyles.join(', ') + "\" on <" + element.nodeName.toLowerCase() + " " + (styles &&
            "style={" + JSON.stringify(styles) + "}") + "> element.\n\nReconciled css (css variables replaced with actual values):\n" + css + "\n\nOriginal css:\n" + ((styleElement && styleElement.textContent) || '') + "\n"; },
    };
}
exports.toHaveCompiledCss = toHaveCompiledCss;
//# sourceMappingURL=matchers.js.map